<?php
/**
* DeliciousPlugin.class.php
* 
* Plugin zur Anzeige von del.icio.us-Bookmakrs
* 
* @author               Tobias Thelen <tobias.thelen@uni-osnabrueck.de>
* @version              $Id: $
*/

// +---------------------------------------------------------------------------+
// This file is a plugin for Stud.IP
// DeliciousPlugin.class.php
// Copyright (C) 2007 Tobias Thelen <tobias.thelen@uni-osnabrueck.de>
// +---------------------------------------------------------------------------+
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or any later version.
// +---------------------------------------------------------------------------+
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// +---------------------------------------------------------------------------+

require_once('lib/classes/UserConfig.class.php');

class DeliciousPlugin extends AbstractStudIPHomepagePlugin {

	var $nav_ok;
	
	function DeliciousPlugin(){
		parent::AbstractStudIPHomepagePlugin();
		$this->setPluginIconName('img/delicious.med.gif');
		$nav_ok = false;
	}
		
	function hasNavigation(){
		if (!$this->nav_ok) $this->buildMenu();
		return parent::hasNavigation();
	}
	
	function getNavigation(){
		if (!$this->nav_ok) $this->buildMenu();
		return parent::getNavigation();
	}
	
	function getStatusShowOverviewPage(){
		$uc=new UserConfig();
		// only show, if activated
		if ($uc->getValue($this->requesteduser->getUserid(),"DELICIOUS_USERNAME")) return 1;
		else return 0;
	}
	
	function getLink($params = array()){
		return PluginEngine::getLink($this, $params);
	}
	
	function getDisplaytitle(){
		if ($this->user->isSameUser($this->requesteduser)) {
			return _("meine del.icio.us Bookmarks");
			//return parent::getDisplaytitle();
		}
		return sprintf(_("%s's del.icio.us Bookmarks"),htmlReady($this->requesteduser->getGivenname()));
	}
	
	function buildMenu(){
		$tab = new PluginNavigation();
		if ($this->user->isSameUser($this->requesteduser)) {
			$tab->setDisplayname(_("del.icio.us"));
			$this->setNavigation($tab); 
			$this->setNavigationPosition(10);
		}
		$this->nav_ok = true;
	}

	function showOverview() {
		$this->_show_linkroll($this->requesteduser->getUserid());
		$this->_show_tagroll($this->requesteduser->getUserid());
	}
	
	function actionShowAdministrationPage(){
		$this->showAdministrationPage();
	}

	function showAdministrationPage(){
		$this->show();
	}
	
	function show() {
		// show config and preview dialog
		if (!$this->user->isSameUser($this->requesteduser)) die;
		$deliciouscmd = (isset($_REQUEST['deliciouscmd']))? $_REQUEST['deliciouscmd']:'';

		$uc=new UserConfig();
		$userid=$this->user->getUserid();
		$d_un=$uc->getValue($userid, "DELICIOUS_USERNAME");
		switch ($deliciouscmd) {
			case 'update':
				if ($_REQUEST['delicious_username']) {
					$uc->setValue(htmlspecialchars($_REQUEST['delicious_username']), $userid, "DELICIOUS_USERNAME");
				} else {
					$uc->unsetValue($userid, "DELICIOUS_USERNAME");
				}
				if (!$d_un) break; // don't overwrite default data on first activation
				$uc->setValue($_REQUEST['delicious_linkroll'], $userid, "DELICIOUS_LINKROLL");
				$lroll_args['icon']="rss";
				$lroll_args['count']=$_REQUEST['lroll_count'];
				$lroll_args['title']=urlencode(htmlspecialchars($_REQUEST['lroll_title']));
				$lroll_args['tags']=$_REQUEST['lroll_tags'];
				$lroll_args['extended']=$_REQUEST['lroll_extended'];
				$lroll_tags=$_REQUEST['lroll_onlytags'];
				$uc->setValue($lroll_tags, $userid, "DELICIOUS_LINKROLL_TAGS");
				$lroll_args['sort']=$_REQUEST['lroll_sort'];
				$lroll_data=$this->_make_delicious_data($lroll_args);
				$uc->setValue(htmlspecialchars($lroll_data),$userid, "DELICIOUS_LINKROLL_DATA");
				
				$uc->setValue($_REQUEST['delicious_tagroll'], $userid, "DELICIOUS_TAGROLL");
				$troll_args['count']=$_REQUEST['troll_count'];
				$troll_args['icon']='_set_';
				$troll_args['title']=urlencode(htmlspecialchars($_REQUEST['troll_title']));
				$troll_args['size']=$_REQUEST['troll_size'];
				$troll_args['flow']=$_REQUEST['troll_flow'];
				$troll_args['totals']=$_REQUEST['troll_totals'];
				$troll_args['sort']=$_REQUEST['troll_sort'];
				$troll_args['color']=$_REQUEST['troll_color'];
				$troll_data=$this->_make_delicious_data($troll_args);
				$uc->setValue(htmlspecialchars($troll_data),$userid, "DELICIOUS_TAGROLL_DATA");
				
			default:
			;
		}
		
		// get data
		$d_un=$uc->getValue($userid, "DELICIOUS_USERNAME");
		// linkroll
		$lroll=$uc->getValue($userid, "DELICIOUS_LINKROLL");
		$troll=$uc->getValue($userid, "DELICIOUS_TAGROLL");
		$lroll_data=$uc->getValue($userid, "DELICIOUS_LINKROLL_DATA");
		$lroll_args=$this->_get_delicious_args($lroll_data);
		$lroll_tags=$uc->getValue($userid, "DELICIOUS_LINKROLL_TAGS");
		// tagroll
		$troll_data=$uc->getValue($userid, "DELICIOUS_TAGROLL_DATA");
		$troll_args=$this->_get_delicious_args($troll_data);
		
		echo '<table width="100%" class="blank" border="0" cellpadding="0" cellspacing="0" >', "\n";
		echo '<tr><td class="blank" valign="top" align="left">';
		echo "<table cellpadding=20 cellspacing=0>";
		
		// config table
		echo "<tr><td width=50% valign=top>";
		$url=PluginEngine::getLink($this,array("username" => $this->username),"showAdministrationPage");
		echo "<form action='$url' method='post'>";
		echo "<input type='hidden' name='deliciouscmd' value='update'>";
		echo "<table cellpadding=3 cellspacing=0>";
		echo "<tr><td colspan=2>"._("Um Ihre del.icio.us-Bookmarks auf Ihrer persnlichen Homepage anzeigen zu lassen, geben Sie Ihren del.icio.us-Benutzernamen ein. Zum Deaktivieren der Anzeige entfernen Sie den Namen wieder.")."</td></tr>";
		// del.icio.us username
		echo "<tr class='steelgraulight'><td colspan=2 style='padding:12px;'>del.icio.us Benutzername: ";
		echo "<input type='text' size=30 name='delicious_username' value='".$d_un."'></td></tr>";
		echo "<tr><td colspan=2>&nbsp;</td></tr>";
		if ($d_un) {
			echo "<tr class=steelkante>"; // linkroll
			echo "<td><input type='checkbox' name='delicious_linkroll'".($lroll?" checked":"")."></td>";
			echo "<td width=100%><b>"._("Link-Roll anzeigen")."</b></td></tr>";
			echo "<tr><td></td><td>"; // title
			echo "Titel: <input type=text size=25 name='lroll_title' value='".urldecode($lroll_args['title'])."'>";
			echo "</td></tr>";
			echo "<tr><td></td><td>"; // count
			echo "Zeige <input type=text size=2 name='lroll_count' value='".$lroll_args['count']."'> Eintrge";
			echo "</td></tr>";
			echo "<tr><td></td><td>"; // tags
			echo "<input type=checkbox name='lroll_tags' value='_set_' ".($lroll_args['tags']?"checked":"").">"._("Tags einblenden");
			echo "</td></tr>";
			echo "<tr><td></td><td>"; // extended
			echo "<input type=checkbox name='lroll_extended' value='_set_' ".($lroll_args['extended']?"checked":"").">"._("Notizen anzeigen");
			echo "</td></tr>";
			echo "<tr><td></td><td>"; // only tags
			echo _("Tags einschrnken:")." <input type=text size=15 name='lroll_onlytags' value=".$lroll_tags."> (Verknpfung mit +)";
			echo "</td></tr>";
			echo "<tr><td></td><td>"; // sortierung
			echo _("Sortierung")." ";
			echo "<input type='radio' name='lroll_sort' value='alpha' ".($lroll_args['sort']!='recent'?" checked":"")."> "._("alphabetisch");
			echo "<input type='radio' name='lroll_sort' value='recent' ".($lroll_args['sort']=='recent'?" checked":"")."> "._("neue nach oben");
			echo "</td></tr>";
			
			echo "<tr class=steelkante>"; // tagroll
			echo "<td><input type='checkbox' name='delicious_tagroll'".($troll?" checked":"")."></td>";
			echo "<td><b>"._("Tag-Roll anzeigen")."</b></td></tr>";
			echo "<tr><td></td><td>"; // title
			echo "Titel: <input type=text size=25 name='troll_title' value='".urldecode($troll_args['title'])."'>";
			echo "</td></tr>";
			echo "<tr><td></td><td>"; // count
			echo "Zeige <input type=text size=2 name='troll_count' value='".$troll_args['count']."'> Eintrge";
			echo "</td></tr>";
			echo "<tr><td></td><td>"; // size
			echo "Gre: <input type=text size=6 name='troll_size' value='".$troll_args['size']."'> (z.B. 12-35)";
			echo "</td></tr>";
			echo "<tr><td></td><td>"; // flow
			echo "als <input type='radio' name='troll_flow' value='cloud' ".($troll_args['flow']=='cloud'?" checked":"")."> Cloud ";
			echo "<input type='radio' name='troll_flow' value='list' ".($troll_args['flow']=='list'?" checked":"")."> Liste ";
			echo "</td></tr>";
			echo "<tr><td></td><td>"; // totals
			echo "<input type=checkbox name='troll_totals' value='_set_' ".($troll_args['totals']?"checked":"").">"._("Zhler einblenden");
			echo "</td></tr>";
			echo "<tr><td></td><td>"; // sort
			echo _("sortiere nach")." ";
			echo "<input type='radio' name='troll_sort' value='alpha' ".($troll_args['sort']!='freq'?" checked":"")."> "._("Alphabet");
			echo "<input type='radio' name='troll_sort' value='freq' ".($troll_args['sort']=='freq'?" checked":"")."> "._("Hufigkeit");
			echo "</td></tr>";
			echo "<tr><td></td><td>"; // color
			echo _("Farben:")." ";
			echo "<input type=text size=15 name='troll_color' value='".$troll_args['color']."'> (z.B. 87ceeb-0000ff, <a href='http://de.selfhtml.org/helferlein/farben.htm' target='_new'>Hexangaben</a> ohne #)";
		}
		// submit
		echo "<tr><td colspan=2 align=center>";
		echo '&nbsp;<br /><input type="IMAGE" name="update" border="0" align="absmiddle" ' . makeButton("uebernehmen", "src") . ' value="' . _("ver&auml;ndern") . '">';
		echo "</td></tr>";
		echo "</table>";
		echo "</form>";
		echo "</td>";
		
		// preview table
		echo "<td width='50%' valign='top' style='margin-left:5px; border-left:1px black solid; padding:5px;'>";
		if ($d_un) {
			echo "<h2>"._("Vorschau")." $d_un</h2>";
			$this->_show_linkroll($userid);
			$this->_show_tagroll($userid);

		}
		echo "</td>";
		
		echo "</tr></table>";
		echo '<br>&nbsp;</td></tr></table>', "\n";
	}
	
	function _get_delicious_args($argstring) {
		// construct array from del.icio.us url-data
		$args=array();
		foreach (explode(";",$argstring) as $arg) {
			$arglist=explode("=",$arg);
			$args[$arglist[0]]= (count($arglist)==1 ? "_set_" : $arglist[1]);
		}
		return $args;
	}
	
	function _make_delicious_data($args) {
		// construct del.icio.us url-data from array
		$data="";
		$first=1;
		foreach ($args as $a=>$v) {
			if (!$v) continue;
			if ($first) $first=0; else $data.=";";
			if ($v=='_set_') $data.="$a"; else $data.="$a=$v";
		}
		return $data;
	}
	
	function _show_linkroll($user_id) {
		$uc=new UserConfig();
		if (!$uc->getValue($user_id, "DELICIOUS_LINKROLL")) return;
		$username=$uc->getValue($user_id, "DELICIOUS_USERNAME");
		$linkroll_data=$uc->getValue($user_id, "DELICIOUS_LINKROLL_DATA");
		$linkroll_tags=$uc->getValue($user_id, "DELICIOUS_LINKROLL_TAGS");
		#echo "<p>coming in with $username and $linkroll_data";
		$lr='<script type="text/javascript" src="http://del.icio.us/feeds/js/';
		$lr.=$username;
		if ($linkroll_tags) $lr.="/".urlencode($linkroll_tags);
		$lr.='?'.$linkroll_data;
		$lr.='"></script><noscript><a href="http://del.icio.us/tthelen">my del.icio.us</a></noscript>';
		#var_dump(preg_replace("/</","&lt;",$lr));
		echo $lr;
	}
	
	function _show_tagroll($user_id) {
		$uc=new UserConfig();
		if (!$uc->getValue($user_id, "DELICIOUS_TAGROLL")) return;
		$username=$uc->getValue($user_id, "DELICIOUS_USERNAME");
		$tagroll_data=$uc->getValue($user_id, "DELICIOUS_TAGROLL_DATA");
		
		#echo "<p>coming in with $username and $tagroll_data";
		$tr='<script type="text/javascript" src="http://del.icio.us/feeds/js/tags/';
		$tr.=$username.'?'.$tagroll_data;
		$tr.='"></script><noscript><a href="http://del.icio.us/tthelen">my del.icio.us</a></noscript>';
		#var_dump(preg_replace("/</","&lt;",$tr));
		echo $tr;
	}
}
?>
